import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { StartDomainMaintenanceRequest, StartDomainMaintenanceResponse } from "../models/models_0";
import { OpenSearchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../OpenSearchClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link StartDomainMaintenanceCommand}.
 */
export interface StartDomainMaintenanceCommandInput extends StartDomainMaintenanceRequest {
}
/**
 * @public
 *
 * The output of {@link StartDomainMaintenanceCommand}.
 */
export interface StartDomainMaintenanceCommandOutput extends StartDomainMaintenanceResponse, __MetadataBearer {
}
declare const StartDomainMaintenanceCommand_base: {
    new (input: StartDomainMaintenanceCommandInput): import("@smithy/smithy-client").CommandImpl<StartDomainMaintenanceCommandInput, StartDomainMaintenanceCommandOutput, OpenSearchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: StartDomainMaintenanceCommandInput): import("@smithy/smithy-client").CommandImpl<StartDomainMaintenanceCommandInput, StartDomainMaintenanceCommandOutput, OpenSearchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Starts the node maintenance process on the data node. These processes can include a node reboot, an Opensearch or Elasticsearch process restart,
 *    or a Dashboard or Kibana restart.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { OpenSearchClient, StartDomainMaintenanceCommand } from "@aws-sdk/client-opensearch"; // ES Modules import
 * // const { OpenSearchClient, StartDomainMaintenanceCommand } = require("@aws-sdk/client-opensearch"); // CommonJS import
 * const client = new OpenSearchClient(config);
 * const input = { // StartDomainMaintenanceRequest
 *   DomainName: "STRING_VALUE", // required
 *   Action: "REBOOT_NODE" || "RESTART_SEARCH_PROCESS" || "RESTART_DASHBOARD", // required
 *   NodeId: "STRING_VALUE",
 * };
 * const command = new StartDomainMaintenanceCommand(input);
 * const response = await client.send(command);
 * // { // StartDomainMaintenanceResponse
 * //   MaintenanceId: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param StartDomainMaintenanceCommandInput - {@link StartDomainMaintenanceCommandInput}
 * @returns {@link StartDomainMaintenanceCommandOutput}
 * @see {@link StartDomainMaintenanceCommandInput} for command's `input` shape.
 * @see {@link StartDomainMaintenanceCommandOutput} for command's `response` shape.
 * @see {@link OpenSearchClientResolvedConfig | config} for OpenSearchClient's `config` shape.
 *
 * @throws {@link BaseException} (client fault)
 *  <p>An error occurred while processing the request.</p>
 *
 * @throws {@link DisabledOperationException} (client fault)
 *  <p>An error occured because the client wanted to access an unsupported operation.</p>
 *
 * @throws {@link InternalException} (server fault)
 *  <p>Request processing failed because of an unknown error, exception, or internal failure.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>An exception for accessing or deleting a resource that doesn't exist.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>An exception for accessing or deleting a resource that doesn't exist.</p>
 *
 * @throws {@link OpenSearchServiceException}
 * <p>Base exception class for all service exceptions from OpenSearch service.</p>
 *
 * @public
 */
export declare class StartDomainMaintenanceCommand extends StartDomainMaintenanceCommand_base {
}
